CreateFiles class

This is the main control, to return help or create

Constructors

CreateFiles()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

help() → dynamic
Here is help
meet() → void
Here is help
readFiles(String local) → dynamic
Here I create the "Model".dart files